/*********************************************************************
Arithmetic - Do arithmetic operations on images.
Arithmetic is part of GNU Astronomy Utilities (Gnuastro) package.

Original author:
     Mohammad Akhlaghi <mohammad@akhlaghi.org>
Contributing author(s):
Copyright (C) 2015-2018, Free Software Foundation, Inc.

Gnuastro is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

Gnuastro is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
**********************************************************************/
#ifndef OPERANDS_H
#define OPERANDS_H

size_t
operands_num(struct arithmeticparams *p);

void
operands_add(struct arithmeticparams *p, char *filename, gal_data_t *data);

gal_data_t *
operands_pop(struct arithmeticparams *p, char *operator);

void
operands_set_name(struct arithmeticparams *p, char *token);

int
operands_is_name(struct arithmeticparams *p, char *token);

#endif
